summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--xmake/core/base/tty.lua4
1 files changed, 2 insertions, 2 deletions
diff --git a/xmake/core/base/tty.lua b/xmake/core/base/tty.lua
index 30b6abb99..0417f9b8f 100644
--- a/xmake/core/base/tty.lua
+++ b/xmake/core/base/tty.lua
@@ -240,8 +240,8 @@ function tty.has_emoji()
has_emoji = false
end
- -- on msys2/cygwin? disable it
- if has_emoji == nil and (term == "msys2" or term == "cygwin") then
+ -- on msys2/cygwin/powershell? disable it
+ if has_emoji == nil and (term == "msys2" or term == "cygwin" or term == "powershell") then
has_emoji = false
end